import codecs
import os
from setuptools import find_packages, setup

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

setup(
    name="thsdk",
    version="1.7.17",
    description="THSDK",
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(include=["thsdk", "thsdk.*"], exclude=["tests", "tests.*"]),
    include_package_data=True,
    exclude_package_data={
        "": [
            "__pycache__/*",
            "*.py[cod]",
            ".DS_Store",
        ]
    },
    python_requires=">=3.9",
    install_requires=[
        "pandas>=1.3.0",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
    ],
)
